@@ -1,15 +1,18 @@
 from django.db import models
 # Create your models here.
 
+import caching.base
 
-class Trigram(models.Model):
+class Trigram(caching.base.CachingMixin, models.Model):
     word = models.CharField(max_length=250)
     word_i_minus_one = models.CharField(max_length=250)
     word_i_minus_two = models.CharField(max_length=250)
     count = models.IntegerField()
 
+    objects = caching.base.CachingManager()
+
     def get_context(self):
-        return u'%s %s' % (word_i_minus_two,word_i_minus_one)
+        return u'%s %s' % (self.word_i_minus_two,self.word_i_minus_one)
 
 class Bigram(models.Model):
     word = models.CharField(max_length=250)
@@ -17,4 +20,4 @@ class Bigram(models.Model):
     count = models.IntegerField()
 
     def get_context(self):
-        return u'%s %s' % (word_i_minus_two,word_i_minus_one)
+        return u'%s' % (self.word_i_minus_one)
